==> haskell-tar-0.5.1.1-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar
version:              0.5.1.1
visibility:           public
id:                   tar-0.5.1.1-AFnzRcxDjjT6h9zOVvLDFV
key:                  tar-0.5.1.1-AFnzRcxDjjT6h9zOVvLDFV
license:              BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:             Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:             Codec
abi:                  23cf2036359e75313ff6de5de82644a0
exposed:              True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index

hidden-modules:
    Codec.Archive.Tar.Types Codec.Archive.Tar.Read
    Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
    Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
    Codec.Archive.Tar.Index.IntTrie

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tar-0.5.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tar-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar
hs-libraries:         HStar-0.5.1.1-AFnzRcxDjjT6h9zOVvLDFV
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.2 filepath-1.4.2.1 time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:         /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.1.1-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar
version:              0.5.1.1
visibility:           public
id:                   tar-0.5.1.1-3tDEHFHWvsFJbzFCROVxZJ
key:                  tar-0.5.1.1-3tDEHFHWvsFJbzFCROVxZJ
license:              BSD-3-Clause
copyright:
    2007 Bjorn Bringert <bjorn@bringert.net>
    2008-2016 Duncan Coutts <duncan@community.haskell.org>

maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:
    Duncan Coutts <duncan@community.haskell.org>
    Bjorn Bringert <bjorn@bringert.net>

synopsis:             Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.

    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.

    It also provides features for random access to archive
    content using an index.

category:             Codec
abi:                  0d56bae0a21dda82282db6f2c532d4a4
exposed:              True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index

hidden-modules:
    Codec.Archive.Tar.Types Codec.Archive.Tar.Read
    Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
    Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
    Codec.Archive.Tar.Index.IntTrie

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tar-0.5.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tar-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar
hs-libraries:         HStar-0.5.1.1-3tDEHFHWvsFJbzFCROVxZJ
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 filepath-1.4.2.2 time-1.11.1.1

haddock-interfaces:   /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html:         /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
